# Pyutttils [![Build package and publish to PyPi](https://github.com/larueli/pyutttils/actions/workflows/pypi.yml/badge.svg?branch=master)](https://github.com/larueli/pyutttils/actions/workflows/pypi.yml) [![Build docs and publish to github pages](https://github.com/larueli/pyutttils/actions/workflows/gh-pages.yml/badge.svg?branch=master)](https://github.com/larueli/pyutttils/actions/workflows/gh-pages.yml)

Ce package permet de fournir des fonctions utilitaires pour l'Université de Technologie de Troyes.

# Quickstart

`pip install pyutttils`

Dans votre code python :

```
from pyutttils import utt_auth
sessionSMTP = utt_auth.smtp() 
```

# Documentation

La documentation du package se trouve à [https://larueli.github.io/pyutttils/](https://larueli.github.io/pyutttils/)